@@ -1,9 +1,9 @@
 //
-// "$Id: Fl_Light_Button.H,v 1.5 1999/02/16 21:59:39 mike Exp $"
+// "$Id: Fl_Light_Button.H,v 1.5.2.3.2.3 2003/01/30 21:39:26 easysw Exp $"
 //
 // Lighted button header file for the Fast Light Tool Kit (FLTK).
 //
-// Copyright 1998-1999 by Bill Spitzak and others.
+// Copyright 1998-2003 by Bill Spitzak and others.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Library General Public
@@ -20,7 +20,7 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 // USA.
 //
-// Please report all bugs and problems to "fltk-bugs@easysw.com".
+// Please report all bugs and problems to "fltk-bugs@fltk.org".
 //
 
 #ifndef Fl_Light_Button_H
@@ -28,16 +28,16 @@
 
 #include "Fl_Button.H"
 
-class Fl_Light_Button : public Fl_Button {
+class FL_EXPORT Fl_Light_Button : public Fl_Button {
 protected:
-    virtual FL_EXPORT void draw();
+    virtual void draw();
 public:
-    virtual FL_EXPORT int handle(int);
-    FL_EXPORT Fl_Light_Button(int x,int y,int w,int h,const char *l = 0);
+    virtual int handle(int);
+    Fl_Light_Button(int x,int y,int w,int h,const char *l = 0);
 };
 
 #endif
 
 //
-// End of "$Id: Fl_Light_Button.H,v 1.5 1999/02/16 21:59:39 mike Exp $".
+// End of "$Id: Fl_Light_Button.H,v 1.5.2.3.2.3 2003/01/30 21:39:26 easysw Exp $".
 //
